@@ -1,14 +1,27 @@
 /*
     This file is part of the KContacts framework.
-    SPDX-FileCopyrightText: 2007 Tobias Koenig <tokoe@kde.org>
+    Copyright (c) 2007 Tobias Koenig <tokoe@kde.org>
 
-    SPDX-License-Identifier: LGPL-2.0-or-later
+    This library is free software; you can redistribute it and/or
+    modify it under the terms of the GNU Library General Public
+    License as published by the Free Software Foundation; either
+    version 2 of the License, or (at your option) any later version.
+
+    This library is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+    Library General Public License for more details.
+
+    You should have received a copy of the GNU Library General Public License
+    along with this library; see the file COPYING.LIB.  If not, write to
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 */
-// krazy:excludeall=contractions
+//krazy:excludeall=contractions
 
 #include "addresseetest.h"
 #include "kcontacts/addressee.h"
-#include <QTest>
+#include <qtest.h>
 
 QTEST_MAIN(AddresseeTest)
 
@@ -18,7 +31,7 @@ void AddresseeTest::emptyTest()
     QVERIFY(addressee.isEmpty());
 
     KContacts::Addressee addresseeWithMail;
-    addresseeWithMail.addEmail(QStringLiteral("foo@bar.org"));
+    addresseeWithMail.insertEmail(QStringLiteral("foo@bar.org"));
     QVERIFY(!addresseeWithMail.isEmpty());
 }
 
@@ -56,7 +69,7 @@ void AddresseeTest::storeTest()
     addressee.setPrefix(QStringLiteral("Sir"));
     addressee.setSuffix(QStringLiteral("II"));
     addressee.setNickName(QStringLiteral("ghosthunter"));
-    addressee.setBirthday(QDate(1982, 7, 19));
+    addressee.setBirthday(QDateTime(QDate(1982, 7, 19)));
     addressee.setMailer(QStringLiteral("mutt"));
     addressee.setTimeZone(KContacts::TimeZone(2));
     addressee.setGeo(KContacts::Geo(42, 23));
@@ -65,7 +78,7 @@ void AddresseeTest::storeTest()
     addressee.setOrganization(QStringLiteral("Scottland Yard"));
     addressee.setNote(QStringLiteral("Don't cross black deads way..."));
     addressee.setProductId(QStringLiteral("ProductId45"));
-    addressee.setRevision(QDateTime(QDate(1982, 9, 15).startOfDay()));
+    addressee.setRevision(QDateTime(QDate(1982, 9, 15)));
     addressee.setSortString(QStringLiteral("Name"));
     KContacts::ResourceLocatorUrl url;
     url.setUrl(QUrl(QStringLiteral("www.scottlandyard.info")));
@@ -80,37 +93,29 @@ void AddresseeTest::storeTest()
     addressee.setCustoms(customs);
     addressee.setKind(QStringLiteral("foo"));
     addressee.setChanged(false);
-    KContacts::Impp imp;
-    imp.setAddress(QUrl(QStringLiteral("gg:foo@kde.org")));
-    KContacts::Impp::List listImp;
-    listImp << imp;
-    addressee.setImppList(listImp);
 
-    QVERIFY(addressee.imppList() == listImp);
     QVERIFY(addressee.langs() == (KContacts::Lang::List() << lang));
     QVERIFY(addressee.gender() == gender);
-    QVERIFY(addressee.uid() == QLatin1String("My uid"));
-    QVERIFY(addressee.name() == QLatin1String("John Sinclair"));
-    QVERIFY(addressee.formattedName() == QLatin1String("Sinclair, John"));
-    QVERIFY(addressee.familyName() == QLatin1String("Sinclair"));
-    QVERIFY(addressee.givenName() == QLatin1String("John"));
-    QVERIFY(addressee.additionalName() == QLatin1String("Bob"));
-    QVERIFY(addressee.prefix() == QLatin1String("Sir"));
-    QVERIFY(addressee.suffix() == QLatin1String("II"));
-    QVERIFY(addressee.nickName() == QLatin1String("ghosthunter"));
-    QVERIFY(addressee.birthday().date() == QDate(1982, 7, 19));
-    QVERIFY(addressee.birthday().time() == QTime(0, 0));
-    QVERIFY(!addressee.birthdayHasTime());
-    QVERIFY(addressee.mailer() == QLatin1String("mutt"));
+    QVERIFY(addressee.uid() == QStringLiteral("My uid"));
+    QVERIFY(addressee.name() == QStringLiteral("John Sinclair"));
+    QVERIFY(addressee.formattedName() == QStringLiteral("Sinclair, John"));
+    QVERIFY(addressee.familyName() == QStringLiteral("Sinclair"));
+    QVERIFY(addressee.givenName() == QStringLiteral("John"));
+    QVERIFY(addressee.additionalName() == QStringLiteral("Bob"));
+    QVERIFY(addressee.prefix() == QStringLiteral("Sir"));
+    QVERIFY(addressee.suffix() == QStringLiteral("II"));
+    QVERIFY(addressee.nickName() == QStringLiteral("ghosthunter"));
+    QVERIFY(addressee.birthday() == QDateTime(QDate(1982, 7, 19)));
+    QVERIFY(addressee.mailer() == QStringLiteral("mutt"));
     QVERIFY(addressee.timeZone() == KContacts::TimeZone(2));
     QVERIFY(addressee.geo() == KContacts::Geo(42, 23));
-    QVERIFY(addressee.title() == QLatin1String("Ghost Hunter"));
-    QVERIFY(addressee.role() == QLatin1String("Leader"));
-    QVERIFY(addressee.organization() == QLatin1String("Scottland Yard"));
-    QVERIFY(addressee.note() == QLatin1String("Don't cross black deads way..."));
-    QVERIFY(addressee.productId() == QLatin1String("ProductId45"));
-    QVERIFY(addressee.revision() == QDateTime(QDate(1982, 9, 15).startOfDay()));
-    QVERIFY(addressee.sortString() == QLatin1String("Name"));
+    QVERIFY(addressee.title() == QStringLiteral("Ghost Hunter"));
+    QVERIFY(addressee.role() == QStringLiteral("Leader"));
+    QVERIFY(addressee.organization() == QStringLiteral("Scottland Yard"));
+    QVERIFY(addressee.note() == QStringLiteral("Don't cross black deads way..."));
+    QVERIFY(addressee.productId() == QStringLiteral("ProductId45"));
+    QVERIFY(addressee.revision() == QDateTime(QDate(1982, 9, 15)));
+    QVERIFY(addressee.sortString() == QStringLiteral("Name"));
     QVERIFY(addressee.url() == url);
     QVERIFY(addressee.secrecy() == KContacts::Secrecy(KContacts::Secrecy::Public));
     QVERIFY(addressee.logo() == logo);
@@ -126,8 +131,7 @@ void AddresseeTest::storeTest()
 
 void AddresseeTest::equalsTest()
 {
-    KContacts::Addressee addressee1;
-    KContacts::Addressee addressee2;
+    KContacts::Addressee addressee1, addressee2;
 
     KContacts::Picture logo(QStringLiteral("http://scottlandyard.info/pics/logo.png"));
     KContacts::Picture photo(QStringLiteral("http://scottlandyard.info/~sinclair/photo.png"));
@@ -154,7 +158,7 @@ void AddresseeTest::equalsTest()
     addressee1.setPrefix(QStringLiteral("Sir"));
     addressee1.setSuffix(QStringLiteral("II"));
     addressee1.setNickName(QStringLiteral("ghosthunter"));
-    addressee1.setBirthday(QDateTime(QDate(1982, 7, 19).startOfDay()));
+    addressee1.setBirthday(QDateTime(QDate(1982, 7, 19)));
     addressee1.setMailer(QStringLiteral("mutt"));
     addressee1.setTimeZone(KContacts::TimeZone(2));
     addressee1.setGeo(KContacts::Geo(42, 23));
@@ -163,7 +167,7 @@ void AddresseeTest::equalsTest()
     addressee1.setOrganization(QStringLiteral("Scottland Yard"));
     addressee1.setNote(QStringLiteral("Don't cross black deads way..."));
     addressee1.setProductId(QStringLiteral("ProductId45"));
-    addressee1.setRevision(QDateTime(QDate(1982, 9, 15).startOfDay()));
+    addressee1.setRevision(QDateTime(QDate(1982, 9, 15)));
     addressee1.setSortString(QStringLiteral("Name"));
     KContacts::ResourceLocatorUrl url;
     url.setUrl(QUrl(QStringLiteral("www.scottlandyard.info")));
@@ -187,7 +191,7 @@ void AddresseeTest::equalsTest()
     addressee2.setPrefix(QStringLiteral("Sir"));
     addressee2.setSuffix(QStringLiteral("II"));
     addressee2.setNickName(QStringLiteral("ghosthunter"));
-    addressee2.setBirthday(QDateTime(QDate(1982, 7, 19).startOfDay()));
+    addressee2.setBirthday(QDateTime(QDate(1982, 7, 19)));
     addressee2.setMailer(QStringLiteral("mutt"));
     addressee2.setTimeZone(KContacts::TimeZone(2));
     addressee2.setGeo(KContacts::Geo(42, 23));
@@ -196,7 +200,7 @@ void AddresseeTest::equalsTest()
     addressee2.setOrganization(QStringLiteral("Scottland Yard"));
     addressee2.setNote(QStringLiteral("Don't cross black deads way..."));
     addressee2.setProductId(QStringLiteral("ProductId45"));
-    addressee2.setRevision(QDateTime(QDate(1982, 9, 15).startOfDay()));
+    addressee2.setRevision(QDateTime(QDate(1982, 9, 15)));
     addressee2.setSortString(QStringLiteral("Name"));
     addressee2.setUrl(url);
     addressee2.setSecrecy(KContacts::Secrecy(KContacts::Secrecy::Public));
@@ -214,8 +218,7 @@ void AddresseeTest::equalsTest()
 
 void AddresseeTest::differsTest()
 {
-    KContacts::Addressee addressee1;
-    KContacts::Addressee addressee2;
+    KContacts::Addressee addressee1, addressee2;
 
     addressee1.setNameFromString(QStringLiteral("John Sinclair"));
     addressee2.setNameFromString(QStringLiteral("Suko"));
@@ -225,8 +228,7 @@ void AddresseeTest::differsTest()
 
 void AddresseeTest::assignmentTest()
 {
-    KContacts::Addressee addressee1;
-    KContacts::Addressee addressee2;
+    KContacts::Addressee addressee1, addressee2;
 
     KContacts::Picture logo(QStringLiteral("http://scottlandyard.info/pics/logo.png"));
     KContacts::Picture photo(QStringLiteral("http://scottlandyard.info/~sinclair/photo.png"));
@@ -253,7 +255,7 @@ void AddresseeTest::assignmentTest()
     addressee1.setPrefix(QStringLiteral("Sir"));
     addressee1.setSuffix(QStringLiteral("II"));
     addressee1.setNickName(QStringLiteral("ghosthunter"));
-    addressee1.setBirthday(QDateTime(QDate(1982, 7, 19).startOfDay()));
+    addressee1.setBirthday(QDateTime(QDate(1982, 7, 19)));
     addressee1.setMailer(QStringLiteral("mutt"));
     addressee1.setTimeZone(KContacts::TimeZone(2));
     addressee1.setGeo(KContacts::Geo(42, 23));
@@ -262,7 +264,7 @@ void AddresseeTest::assignmentTest()
     addressee1.setOrganization(QStringLiteral("Scottland Yard"));
     addressee1.setNote(QStringLiteral("Don't cross black deads way..."));
     addressee1.setProductId(QStringLiteral("ProductId45"));
-    addressee1.setRevision(QDateTime(QDate(1982, 9, 15).startOfDay()));
+    addressee1.setRevision(QDateTime(QDate(1982, 9, 15)));
     addressee1.setSortString(QStringLiteral("Name"));
     KContacts::ResourceLocatorUrl url;
     url.setUrl(QUrl(QStringLiteral("www.scottlandyard.info")));
@@ -284,8 +286,7 @@ void AddresseeTest::assignmentTest()
 
 void AddresseeTest::serializeTest()
 {
-    KContacts::Addressee addressee1;
-    KContacts::Addressee addressee2;
+    KContacts::Addressee addressee1, addressee2;
 
     KContacts::Picture logo(QStringLiteral("http://scottlandyard.info/pics/logo.png"));
     KContacts::Picture photo(QStringLiteral("http://scottlandyard.info/~sinclair/photo.png"));
@@ -301,7 +302,8 @@ void AddresseeTest::serializeTest()
     categories << QStringLiteral("Helper") << QStringLiteral("Friend");
 
     QStringList customs;
-    customs << QStringLiteral("FirstApp-FirstKey:FirstValue") << QStringLiteral("SecondApp-SecondKey:SecondValue")
+    customs << QStringLiteral("FirstApp-FirstKey:FirstValue")
+            << QStringLiteral("SecondApp-SecondKey:SecondValue")
             << QStringLiteral("ThirdApp-ThirdKey:ThirdValue");
 
     addressee1.setUid(QStringLiteral("My uid"));
@@ -313,7 +315,7 @@ void AddresseeTest::serializeTest()
     addressee1.setPrefix(QStringLiteral("Sir"));
     addressee1.setSuffix(QStringLiteral("II"));
     addressee1.setNickName(QStringLiteral("ghosthunter"));
-    addressee1.setBirthday(QDateTime(QDate(1982, 7, 19).startOfDay()));
+    addressee1.setBirthday(QDateTime(QDate(1982, 7, 19)));
     addressee1.setMailer(QStringLiteral("mutt"));
     addressee1.setTimeZone(KContacts::TimeZone(2));
     addressee1.setGeo(KContacts::Geo(42, 23));
@@ -322,7 +324,7 @@ void AddresseeTest::serializeTest()
     addressee1.setOrganization(QStringLiteral("Scottland Yard"));
     addressee1.setNote(QStringLiteral("Don't cross black deads way..."));
     addressee1.setProductId(QStringLiteral("ProductId45"));
-    addressee1.setRevision(QDateTime(QDate(1982, 9, 15).startOfDay()));
+    addressee1.setRevision(QDateTime(QDate(1982, 9, 15)));
     addressee1.setSortString(QStringLiteral("Name"));
     KContacts::ResourceLocatorUrl url;
     url.setUrl(QUrl(QStringLiteral("www.scottlandyard.info")));
@@ -355,7 +357,8 @@ void AddresseeTest::fullEmailTest()
     emails << QStringLiteral("foo@bar.com");
     a.setEmails(emails);
     a.setFormattedName(QStringLiteral("firstname \"nickname\" lastname"));
-    QCOMPARE(a.fullEmail(), QStringLiteral("\"firstname \\\"nickname\\\" lastname\" <foo@bar.com>"));
+    QCOMPARE(a.fullEmail(),
+             QStringLiteral("\"firstname \\\"nickname\\\" lastname\" <foo@bar.com>"));
 }
 
 void AddresseeTest::nameFromStringTest()
@@ -380,7 +383,7 @@ void AddresseeTest::customFieldsTest()
     QCOMPARE(a.custom(QStringLiteral("MyApp"), QStringLiteral("MyKey")), QStringLiteral("MyValue"));
 
     a.insertCustom(QStringLiteral("MyApp"), QStringLiteral("MyKey"), QStringLiteral("YourValue"));
-    QCOMPARE(a.customs().count(), 1); // still one, we overwrite...
+    QCOMPARE(a.customs().count(), 1);   // still one, we overwrite...
     QCOMPARE(a.custom(QStringLiteral("MyApp"), QStringLiteral("MyKey")), QStringLiteral("YourValue"));
 
     // test query non-existing app/key
@@ -400,7 +403,7 @@ void AddresseeTest::customFieldsTest()
     QCOMPARE(a.custom(QStringLiteral("MyApp"), QStringLiteral("AnotherKey")), QStringLiteral("OtherValue"));
     QCOMPARE(a.custom(QStringLiteral("MyApp"), QStringLiteral("MyKey")), QStringLiteral("YourValue"));
 
-#if 0 // Order is not defined now as we use a QHash
+#if 0 //Order is not defined now as we use a QHash
     // test customs
     QCOMPARE(a.customs().at(0), QStringLiteral("MyApp-MyKey:YourValue"));
     QCOMPARE(a.customs().at(1), QStringLiteral("MyApp-AnotherKey:OtherValue"));
@@ -423,9 +426,9 @@ void AddresseeTest::customFieldsTest()
     c.insertCustom(QStringLiteral("ThisApp"), QStringLiteral("ShouldNotBe"), QStringLiteral("There"));
     QCOMPARE(c.customs().count(), 1);
 
-    const QStringList testData = QStringList() << QStringLiteral("FirstApp-FirstKey:FirstValue") //
-                                               << QStringLiteral("SecondApp-SecondKey:SecondValue") //
-                                               << QStringLiteral("ThirdApp-ThirdKey:ThirdValue");
+    const QStringList testData = QStringList() << QStringLiteral("FirstApp-FirstKey:FirstValue")
+                                 << QStringLiteral("SecondApp-SecondKey:SecondValue")
+                                 << QStringLiteral("ThirdApp-ThirdKey:ThirdValue");
 
     c.setCustoms(testData);
     QCOMPARE(c.customs().count(), 3);
@@ -466,5 +469,3 @@ void AddresseeTest::parseEmailAddress()
     QCOMPARE(parsedEmail, email);
     QCOMPARE(parsedName, name);
 }
-
-#include "moc_addresseetest.cpp"
