@@ -1,31 +1,41 @@
 /*
     This file is part of the KContacts framework.
-    SPDX-FileCopyrightText: 2002 Cornelius Schumacher <schumacher@kde.org>
+    Copyright (c) 2002 Cornelius Schumacher <schumacher@kde.org>
 
-    SPDX-License-Identifier: LGPL-2.0-or-later
+    This library is free software; you can redistribute it and/or
+    modify it under the terms of the GNU Library General Public
+    License as published by the Free Software Foundation; either
+    version 2 of the License, or (at your option) any later version.
+
+    This library is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+    Library General Public License for more details.
+
+    You should have received a copy of the GNU Library General Public License
+    along with this library; see the file COPYING.LIB.  If not, write to
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 */
 
-#include "field.h"
+#include <klocalizedstring.h>
+#include <kconfig.h>
 
-#if KCONTACTS_BUILD_DEPRECATED_SINCE(5, 88)
-#include <KConfig>
-#include <KLocalizedString>
-#include <KConfigGroup>
+#include <kconfiggroup.h>
 #include <KSharedConfig>
+#include "field.h"
 
 using namespace KContacts;
 
-class Q_DECL_HIDDEN Field::Private
+class Field::Private
 {
 public:
-    Private(int fieldId, int category = 0, const QString &label = QString(), const QString &key = QString(), const QString &app = QString())
-        : mFieldId(fieldId)
-        , mCategory(category)
-        , mLabel(label)
-        , mKey(key)
-        , mApp(app)
-    {
-    }
+    Private(int fieldId, int category = 0,
+            const QString &label = QString(),
+            const QString &key = QString(),
+            const QString &app = QString())
+        : mFieldId(fieldId), mCategory(category), mLabel(label),
+          mKey(key), mApp(app) {}
 
     enum FieldId {
         CustomField,
@@ -66,14 +76,13 @@ public:
         Organization,
         Department,
         Note,
-        Url,
+        Url
     };
 
     int fieldId() const
     {
         return mFieldId;
     }
-
     int category() const
     {
         return mCategory;
@@ -83,12 +92,10 @@ public:
     {
         return mLabel;
     }
-
     QString key() const
     {
         return mKey;
     }
-
     QString app() const
     {
         return mApp;
@@ -236,14 +243,6 @@ QString Field::categoryLabel(int category)
 
 QString Field::value(const KContacts::Addressee &a)
 {
-
-    auto findPhone = [](const PhoneNumber::List &list, PhoneNumber::TypeFlag compareFlag) {
-        auto it = std::find_if(list.cbegin(), list.cend(), [=](const PhoneNumber &phone) {
-            return (phone.type() & ~(PhoneNumber::Pref)) == compareFlag;
-        });
-        return it;
-    };
-
     switch (d->fieldId()) {
     case Private::FormattedName:
         return a.formattedName();
@@ -287,18 +286,22 @@ QString Field::value(const KContacts::Addressee &a)
         {
             // check for preferred number
             const PhoneNumber::List list = a.phoneNumbers(PhoneNumber::Home | PhoneNumber::Pref);
-            auto it = findPhone(list, PhoneNumber::Home);
-            if (it != list.cend()) {
-                return it->number();
+            PhoneNumber::List::ConstIterator end(list.end());
+            for (it = list.begin(); it != end; ++it) {
+                if (((*it).type() & ~(PhoneNumber::Pref)) == PhoneNumber::Home) {
+                    return (*it).number();
+                }
             }
         }
 
         {
             // check for normal home number
             const PhoneNumber::List list = a.phoneNumbers(PhoneNumber::Home);
-            auto it = findPhone(list, PhoneNumber::Home);
-            if (it != list.cend()) {
-                return it->number();
+            PhoneNumber::List::ConstIterator end(list.end());
+            for (it = list.begin(); it != end; ++it) {
+                if (((*it).type() & ~(PhoneNumber::Pref)) == PhoneNumber::Home) {
+                    return (*it).number();
+                }
             }
         }
 
@@ -310,18 +313,21 @@ QString Field::value(const KContacts::Addressee &a)
         {
             // check for preferred number
             const PhoneNumber::List list = a.phoneNumbers(PhoneNumber::Work | PhoneNumber::Pref);
-            auto it = findPhone(list, PhoneNumber::Work);
-            if (it != list.cend()) {
-                return it->number();
+            PhoneNumber::List::ConstIterator end(list.end());
+            for (it = list.begin(); it != end; ++it) {
+                if (((*it).type() & ~(PhoneNumber::Pref)) == PhoneNumber::Work) {
+                    return (*it).number();
+                }
             }
         }
 
         {
             // check for normal work number
             const PhoneNumber::List list = a.phoneNumbers(PhoneNumber::Work);
-            auto it = findPhone(list, PhoneNumber::Work);
-            if (it != list.cend()) {
-                return it->number();
+            for (it = list.begin(); it != list.end(); ++it) {
+                if (((*it).type() & ~(PhoneNumber::Pref)) == PhoneNumber::Work) {
+                    return (*it).number();
+                }
             }
         }
 
@@ -413,7 +419,7 @@ bool Field::setValue(KContacts::Addressee &a, const QString &value)
         a.setNote(value);
         return true;
     case Private::Birthday:
-        a.setBirthday(QDate::fromString(value, Qt::ISODate));
+        a.setBirthday(QDateTime::fromString(value, Qt::ISODate));
         return true;
     case Private::CustomField:
         a.insertCustom(d->app(), d->key(), value);
@@ -455,9 +461,11 @@ QString Field::sortKey(const KContacts::Addressee &a)
     case Private::Birthday:
         if (a.birthday().isValid()) {
             QDate date = a.birthday().date();
-            return QString::asprintf("%02d-%02d", date.month(), date.day());
+            QString key;
+            key.sprintf("%02d-%02d", date.month(), date.day());
+            return key;
         } else {
-            return QStringLiteral("00-00");
+            return QLatin1String("00-00");
         }
     default:
         return value(a).toLower();
@@ -540,29 +548,31 @@ void Field::deleteFields()
     Field::List::ConstIterator it;
 
     for (it = Private::mAllFields.constBegin(); it != Private::mAllFields.constEnd(); ++it) {
-        delete (*it);
+        delete(*it);
     }
     Private::mAllFields.clear();
 
     for (it = Private::mDefaultFields.constBegin(); it != Private::mDefaultFields.constEnd(); ++it) {
-        delete (*it);
+        delete(*it);
     }
     Private::mDefaultFields.clear();
 
     for (it = Private::mCustomFields.constBegin(); it != Private::mCustomFields.constEnd(); ++it) {
-        delete (*it);
+        delete(*it);
     }
     Private::mCustomFields.clear();
 }
 
-void Field::saveFields(const QString &identifier, const Field::List &fields)
+void Field::saveFields(const QString &identifier,
+                       const Field::List &fields)
 {
     KConfigGroup cg(KSharedConfig::openConfig(), "KABCFields");
 
     saveFields(cg, identifier, fields);
 }
 
-void Field::saveFields(KConfigGroup &cfg, const QString &identifier, const Field::List &fields)
+void Field::saveFields(KConfigGroup &cfg, const QString &identifier,
+                       const Field::List &fields)
 {
     QList<int> fieldIds;
 
@@ -576,7 +586,8 @@ void Field::saveFields(KConfigGroup &cfg, const QString &identifier, const Field
             customEntry << (*it)->d->label();
             customEntry << (*it)->d->key();
             customEntry << (*it)->d->app();
-            cfg.writeEntry(QLatin1String("KCONTACTS_CustomEntry_") + identifier + QLatin1Char('_') + QString::number(custom++), customEntry);
+            cfg.writeEntry(QLatin1String("KCONTACTS_CustomEntry_") + identifier + QLatin1Char('_') +
+                           QString::number(custom++), customEntry);
         }
     }
 
@@ -600,11 +611,13 @@ Field::List Field::restoreFields(const KConfigGroup &cfg, const QString &identif
     QList<int>::ConstIterator it;
     fields.reserve(fieldIds.count());
     for (it = fieldIds.begin(); it != fieldIds.end(); ++it) {
-        Private *f = nullptr;
+        Private *f = Q_NULLPTR;
         if ((*it) == Private::CustomField) {
-            QStringList customEntry =
-                cfg.readEntry(QLatin1String("KCONTACTS_CustomEntry_") + identifier + QLatin1Char('_') + QString::number(custom++), QStringList());
-            f = new Private(*it, CustomCategory, customEntry[0], customEntry[1], customEntry[2]);
+            QStringList customEntry = cfg.readEntry(QLatin1String("KCONTACTS_CustomEntry_") +
+                                                    identifier + QLatin1Char('_') +
+                                                    QString::number(custom++), QStringList());
+            f = new Private(*it, CustomCategory, customEntry[ 0 ],
+                            customEntry[ 1 ], customEntry[ 2 ]);
         } else {
             f = new Private(*it);
         }
@@ -629,11 +642,13 @@ bool Field::equals(Field *field)
     return d->key() == field->d->key();
 }
 
-Field *Field::createCustomField(const QString &label, int category, const QString &key, const QString &app)
+Field *Field::createCustomField(const QString &label, int category,
+                                const QString &key, const QString &app)
 {
-    Field *field = new Field(new Private(Private::CustomField, category | CustomCategory, label, key, app));
+    Field *field = new Field(new Private(Private::CustomField,
+                                         category | CustomCategory,
+                                         label, key, app));
     Private::mCustomFields.append(field);
 
     return field;
 }
-#endif
